summaryrefslogtreecommitdiff
path: root/src/de/lmu/ifi/dbs/elki/database/datastore/DataStoreIDMap.java
diff options
context:
space:
mode:
authorAndrej Shadura <andrewsh@debian.org>2019-03-09 22:30:34 +0000
committerAndrej Shadura <andrewsh@debian.org>2019-03-09 22:30:34 +0000
commitb7b404fd7a726774d442562d11659d7b5368cdb9 (patch)
tree6f510ddbf80c1a51e333f80411541565ac71c9e9 /src/de/lmu/ifi/dbs/elki/database/datastore/DataStoreIDMap.java
parentace5fa7f57d49756c0e1b111a30f3b6a9436c1cb (diff)
Import Upstream version 0.5.5
Diffstat (limited to 'src/de/lmu/ifi/dbs/elki/database/datastore/DataStoreIDMap.java')
-rw-r--r--src/de/lmu/ifi/dbs/elki/database/datastore/DataStoreIDMap.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/de/lmu/ifi/dbs/elki/database/datastore/DataStoreIDMap.java b/src/de/lmu/ifi/dbs/elki/database/datastore/DataStoreIDMap.java
index dada881a..cba8e4c9 100644
--- a/src/de/lmu/ifi/dbs/elki/database/datastore/DataStoreIDMap.java
+++ b/src/de/lmu/ifi/dbs/elki/database/datastore/DataStoreIDMap.java
@@ -32,10 +32,10 @@ import de.lmu.ifi.dbs.elki.database.ids.DBIDRef;
*/
public interface DataStoreIDMap {
/**
* Map a DBID to a database id.
*
* @param dbid DBID
* @return record id {@code id >= 0}
*/
- public int map(DBIDRef dbid);
+ int mapDBIDToOffset(DBIDRef dbid);
}
@@ -32,10 +32,10 @@ import de.lmu.ifi.dbs.elki.database.ids.DBIDRef;
public interface DataStoreIDMap {
/**
- * Map a DBID to a database id.
+ * Map a DBID to an array offset.
*
* @param dbid DBID